====================
django-fernet-fields-v2
====================

`Fernet`_ symmetric encryption for Django model fields, using the
`cryptography`_ library and supports  Django >=4.0 .

``django-fernet-fields-v2`` supports `Django`_ 4.0 and later on Python 3.8, 3.9, and 3.10.

Only PostgreSQL, SQLite, and MySQL are tested, but any Django database backend
with support for ``BinaryField`` should work.

.. _Django: http://www.djangoproject.com/
.. _Fernet: https://cryptography.io/en/latest/fernet/
.. _cryptography: https://cryptography.io/en/latest/


Getting Help
============

Fork of https://github.com/orcasgit/django-fernet-fields . See docs there. The only changes made here are to support Django 4.


Contributing
============

See the `contributing docs`_.

.. _contributing docs: https://github.com/MichelML/django-fernet-fields/blob/master/CONTRIBUTING.rst

